import { presetCommon } from "./common.js";
import { presetEverything } from "./everything.js";
import { presetMinimal } from "./minimal.js";
import * as bingo_stratum583 from "bingo-stratum";
import * as zod454 from "zod";

//#region src/presets/index.d.ts
declare const presets: {
  common: bingo_stratum583.Preset<{
    access: zod454.ZodUnion<[zod454.ZodLiteral<"public">, zod454.ZodLiteral<"restricted">]>;
    author: zod454.ZodOptional<zod454.ZodString>;
    bin: zod454.ZodOptional<zod454.ZodUnion<[zod454.ZodString, zod454.ZodRecord<zod454.ZodString, zod454.ZodString>]>>;
    contributors: zod454.ZodOptional<zod454.ZodArray<zod454.ZodObject<{
      avatar_url: zod454.ZodString;
      contributions: zod454.ZodArray<zod454.ZodString, "many">;
      login: zod454.ZodString;
      name: zod454.ZodString;
      profile: zod454.ZodString;
    }, "strip", zod454.ZodTypeAny, {
      avatar_url: string;
      contributions: string[];
      login: string;
      name: string;
      profile: string;
    }, {
      avatar_url: string;
      contributions: string[];
      login: string;
      name: string;
      profile: string;
    }>, "many">>;
    description: zod454.ZodDefault<zod454.ZodString>;
    directory: zod454.ZodString;
    documentation: zod454.ZodObject<{
      development: zod454.ZodOptional<zod454.ZodString>;
      readme: zod454.ZodObject<{
        additional: zod454.ZodOptional<zod454.ZodString>;
        explainer: zod454.ZodOptional<zod454.ZodString>;
        footnotes: zod454.ZodOptional<zod454.ZodString>;
        usage: zod454.ZodOptional<zod454.ZodString>;
      }, "strip", zod454.ZodTypeAny, {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      }, {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      }>;
    }, "strip", zod454.ZodTypeAny, {
      readme: {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      };
      development?: string | undefined;
    }, {
      readme: {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      };
      development?: string | undefined;
    }>;
    email: zod454.ZodEffects<zod454.ZodUnion<[zod454.ZodString, zod454.ZodObject<{
      github: zod454.ZodString;
      npm: zod454.ZodString;
    }, "strip", zod454.ZodTypeAny, {
      github: string;
      npm: string;
    }, {
      github: string;
      npm: string;
    }>]>, {
      github: string;
      npm: string;
    }, string | {
      github: string;
      npm: string;
    }>;
    emoji: zod454.ZodOptional<zod454.ZodString>;
    existingLabels: zod454.ZodOptional<zod454.ZodArray<zod454.ZodObject<{
      color: zod454.ZodString;
      description: zod454.ZodString;
      name: zod454.ZodString;
    }, "strip", zod454.ZodTypeAny, {
      name: string;
      description: string;
      color: string;
    }, {
      name: string;
      description: string;
      color: string;
    }>, "many">>;
    funding: zod454.ZodOptional<zod454.ZodString>;
    guide: zod454.ZodOptional<zod454.ZodObject<{
      href: zod454.ZodString;
      title: zod454.ZodString;
    }, "strip", zod454.ZodTypeAny, {
      href: string;
      title: string;
    }, {
      href: string;
      title: string;
    }>>;
    keywords: zod454.ZodOptional<zod454.ZodArray<zod454.ZodString, "many">>;
    logo: zod454.ZodOptional<zod454.ZodObject<{
      alt: zod454.ZodString;
      height: zod454.ZodOptional<zod454.ZodNumber>;
      src: zod454.ZodString;
      width: zod454.ZodOptional<zod454.ZodNumber>;
    }, "strip", zod454.ZodTypeAny, {
      alt: string;
      src: string;
      height?: number | undefined;
      width?: number | undefined;
    }, {
      alt: string;
      src: string;
      height?: number | undefined;
      width?: number | undefined;
    }>>;
    node: zod454.ZodObject<{
      minimum: zod454.ZodString;
      pinned: zod454.ZodOptional<zod454.ZodString>;
    }, "strip", zod454.ZodTypeAny, {
      minimum: string;
      pinned?: string | undefined;
    }, {
      minimum: string;
      pinned?: string | undefined;
    }>;
    owner: zod454.ZodString;
    packageData: zod454.ZodOptional<zod454.ZodObject<{
      dependencies: zod454.ZodOptional<zod454.ZodRecord<zod454.ZodString, zod454.ZodString>>;
      devDependencies: zod454.ZodOptional<zod454.ZodRecord<zod454.ZodString, zod454.ZodString>>;
      peerDependencies: zod454.ZodOptional<zod454.ZodRecord<zod454.ZodString, zod454.ZodString>>;
      peerDependenciesMeta: zod454.ZodOptional<zod454.ZodRecord<zod454.ZodString, zod454.ZodUnknown>>;
      scripts: zod454.ZodOptional<zod454.ZodRecord<zod454.ZodString, zod454.ZodOptional<zod454.ZodString>>>;
    }, "strip", zod454.ZodTypeAny, {
      dependencies?: Record<string, string> | undefined;
      devDependencies?: Record<string, string> | undefined;
      peerDependencies?: Record<string, string> | undefined;
      peerDependenciesMeta?: Record<string, unknown> | undefined;
      scripts?: Record<string, string | undefined> | undefined;
    }, {
      dependencies?: Record<string, string> | undefined;
      devDependencies?: Record<string, string> | undefined;
      peerDependencies?: Record<string, string> | undefined;
      peerDependenciesMeta?: Record<string, unknown> | undefined;
      scripts?: Record<string, string | undefined> | undefined;
    }>>;
    pnpm: zod454.ZodOptional<zod454.ZodString>;
    repository: zod454.ZodString;
    rulesetId: zod454.ZodOptional<zod454.ZodString>;
    title: zod454.ZodString;
    type: zod454.ZodOptional<zod454.ZodUnion<[zod454.ZodLiteral<"commonjs">, zod454.ZodLiteral<"module">]>>;
    version: zod454.ZodOptional<zod454.ZodString>;
    words: zod454.ZodOptional<zod454.ZodArray<zod454.ZodString, "many">>;
    workflowsVersions: zod454.ZodOptional<zod454.ZodRecord<zod454.ZodString, zod454.ZodRecord<zod454.ZodString, zod454.ZodObject<{
      hash: zod454.ZodOptional<zod454.ZodString>;
      pinned: zod454.ZodOptional<zod454.ZodBoolean>;
    }, "strip", zod454.ZodTypeAny, {
      hash?: string | undefined;
      pinned?: boolean | undefined;
    }, {
      hash?: string | undefined;
      pinned?: boolean | undefined;
    }>>>>;
  }>;
  everything: bingo_stratum583.Preset<{
    access: zod454.ZodUnion<[zod454.ZodLiteral<"public">, zod454.ZodLiteral<"restricted">]>;
    author: zod454.ZodOptional<zod454.ZodString>;
    bin: zod454.ZodOptional<zod454.ZodUnion<[zod454.ZodString, zod454.ZodRecord<zod454.ZodString, zod454.ZodString>]>>;
    contributors: zod454.ZodOptional<zod454.ZodArray<zod454.ZodObject<{
      avatar_url: zod454.ZodString;
      contributions: zod454.ZodArray<zod454.ZodString, "many">;
      login: zod454.ZodString;
      name: zod454.ZodString;
      profile: zod454.ZodString;
    }, "strip", zod454.ZodTypeAny, {
      avatar_url: string;
      contributions: string[];
      login: string;
      name: string;
      profile: string;
    }, {
      avatar_url: string;
      contributions: string[];
      login: string;
      name: string;
      profile: string;
    }>, "many">>;
    description: zod454.ZodDefault<zod454.ZodString>;
    directory: zod454.ZodString;
    documentation: zod454.ZodObject<{
      development: zod454.ZodOptional<zod454.ZodString>;
      readme: zod454.ZodObject<{
        additional: zod454.ZodOptional<zod454.ZodString>;
        explainer: zod454.ZodOptional<zod454.ZodString>;
        footnotes: zod454.ZodOptional<zod454.ZodString>;
        usage: zod454.ZodOptional<zod454.ZodString>;
      }, "strip", zod454.ZodTypeAny, {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      }, {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      }>;
    }, "strip", zod454.ZodTypeAny, {
      readme: {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      };
      development?: string | undefined;
    }, {
      readme: {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      };
      development?: string | undefined;
    }>;
    email: zod454.ZodEffects<zod454.ZodUnion<[zod454.ZodString, zod454.ZodObject<{
      github: zod454.ZodString;
      npm: zod454.ZodString;
    }, "strip", zod454.ZodTypeAny, {
      github: string;
      npm: string;
    }, {
      github: string;
      npm: string;
    }>]>, {
      github: string;
      npm: string;
    }, string | {
      github: string;
      npm: string;
    }>;
    emoji: zod454.ZodOptional<zod454.ZodString>;
    existingLabels: zod454.ZodOptional<zod454.ZodArray<zod454.ZodObject<{
      color: zod454.ZodString;
      description: zod454.ZodString;
      name: zod454.ZodString;
    }, "strip", zod454.ZodTypeAny, {
      name: string;
      description: string;
      color: string;
    }, {
      name: string;
      description: string;
      color: string;
    }>, "many">>;
    funding: zod454.ZodOptional<zod454.ZodString>;
    guide: zod454.ZodOptional<zod454.ZodObject<{
      href: zod454.ZodString;
      title: zod454.ZodString;
    }, "strip", zod454.ZodTypeAny, {
      href: string;
      title: string;
    }, {
      href: string;
      title: string;
    }>>;
    keywords: zod454.ZodOptional<zod454.ZodArray<zod454.ZodString, "many">>;
    logo: zod454.ZodOptional<zod454.ZodObject<{
      alt: zod454.ZodString;
      height: zod454.ZodOptional<zod454.ZodNumber>;
      src: zod454.ZodString;
      width: zod454.ZodOptional<zod454.ZodNumber>;
    }, "strip", zod454.ZodTypeAny, {
      alt: string;
      src: string;
      height?: number | undefined;
      width?: number | undefined;
    }, {
      alt: string;
      src: string;
      height?: number | undefined;
      width?: number | undefined;
    }>>;
    node: zod454.ZodObject<{
      minimum: zod454.ZodString;
      pinned: zod454.ZodOptional<zod454.ZodString>;
    }, "strip", zod454.ZodTypeAny, {
      minimum: string;
      pinned?: string | undefined;
    }, {
      minimum: string;
      pinned?: string | undefined;
    }>;
    owner: zod454.ZodString;
    packageData: zod454.ZodOptional<zod454.ZodObject<{
      dependencies: zod454.ZodOptional<zod454.ZodRecord<zod454.ZodString, zod454.ZodString>>;
      devDependencies: zod454.ZodOptional<zod454.ZodRecord<zod454.ZodString, zod454.ZodString>>;
      peerDependencies: zod454.ZodOptional<zod454.ZodRecord<zod454.ZodString, zod454.ZodString>>;
      peerDependenciesMeta: zod454.ZodOptional<zod454.ZodRecord<zod454.ZodString, zod454.ZodUnknown>>;
      scripts: zod454.ZodOptional<zod454.ZodRecord<zod454.ZodString, zod454.ZodOptional<zod454.ZodString>>>;
    }, "strip", zod454.ZodTypeAny, {
      dependencies?: Record<string, string> | undefined;
      devDependencies?: Record<string, string> | undefined;
      peerDependencies?: Record<string, string> | undefined;
      peerDependenciesMeta?: Record<string, unknown> | undefined;
      scripts?: Record<string, string | undefined> | undefined;
    }, {
      dependencies?: Record<string, string> | undefined;
      devDependencies?: Record<string, string> | undefined;
      peerDependencies?: Record<string, string> | undefined;
      peerDependenciesMeta?: Record<string, unknown> | undefined;
      scripts?: Record<string, string | undefined> | undefined;
    }>>;
    pnpm: zod454.ZodOptional<zod454.ZodString>;
    repository: zod454.ZodString;
    rulesetId: zod454.ZodOptional<zod454.ZodString>;
    title: zod454.ZodString;
    type: zod454.ZodOptional<zod454.ZodUnion<[zod454.ZodLiteral<"commonjs">, zod454.ZodLiteral<"module">]>>;
    version: zod454.ZodOptional<zod454.ZodString>;
    words: zod454.ZodOptional<zod454.ZodArray<zod454.ZodString, "many">>;
    workflowsVersions: zod454.ZodOptional<zod454.ZodRecord<zod454.ZodString, zod454.ZodRecord<zod454.ZodString, zod454.ZodObject<{
      hash: zod454.ZodOptional<zod454.ZodString>;
      pinned: zod454.ZodOptional<zod454.ZodBoolean>;
    }, "strip", zod454.ZodTypeAny, {
      hash?: string | undefined;
      pinned?: boolean | undefined;
    }, {
      hash?: string | undefined;
      pinned?: boolean | undefined;
    }>>>>;
  }>;
  minimal: bingo_stratum583.Preset<{
    access: zod454.ZodUnion<[zod454.ZodLiteral<"public">, zod454.ZodLiteral<"restricted">]>;
    author: zod454.ZodOptional<zod454.ZodString>;
    bin: zod454.ZodOptional<zod454.ZodUnion<[zod454.ZodString, zod454.ZodRecord<zod454.ZodString, zod454.ZodString>]>>;
    contributors: zod454.ZodOptional<zod454.ZodArray<zod454.ZodObject<{
      avatar_url: zod454.ZodString;
      contributions: zod454.ZodArray<zod454.ZodString, "many">;
      login: zod454.ZodString;
      name: zod454.ZodString;
      profile: zod454.ZodString;
    }, "strip", zod454.ZodTypeAny, {
      avatar_url: string;
      contributions: string[];
      login: string;
      name: string;
      profile: string;
    }, {
      avatar_url: string;
      contributions: string[];
      login: string;
      name: string;
      profile: string;
    }>, "many">>;
    description: zod454.ZodDefault<zod454.ZodString>;
    directory: zod454.ZodString;
    documentation: zod454.ZodObject<{
      development: zod454.ZodOptional<zod454.ZodString>;
      readme: zod454.ZodObject<{
        additional: zod454.ZodOptional<zod454.ZodString>;
        explainer: zod454.ZodOptional<zod454.ZodString>;
        footnotes: zod454.ZodOptional<zod454.ZodString>;
        usage: zod454.ZodOptional<zod454.ZodString>;
      }, "strip", zod454.ZodTypeAny, {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      }, {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      }>;
    }, "strip", zod454.ZodTypeAny, {
      readme: {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      };
      development?: string | undefined;
    }, {
      readme: {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      };
      development?: string | undefined;
    }>;
    email: zod454.ZodEffects<zod454.ZodUnion<[zod454.ZodString, zod454.ZodObject<{
      github: zod454.ZodString;
      npm: zod454.ZodString;
    }, "strip", zod454.ZodTypeAny, {
      github: string;
      npm: string;
    }, {
      github: string;
      npm: string;
    }>]>, {
      github: string;
      npm: string;
    }, string | {
      github: string;
      npm: string;
    }>;
    emoji: zod454.ZodOptional<zod454.ZodString>;
    existingLabels: zod454.ZodOptional<zod454.ZodArray<zod454.ZodObject<{
      color: zod454.ZodString;
      description: zod454.ZodString;
      name: zod454.ZodString;
    }, "strip", zod454.ZodTypeAny, {
      name: string;
      description: string;
      color: string;
    }, {
      name: string;
      description: string;
      color: string;
    }>, "many">>;
    funding: zod454.ZodOptional<zod454.ZodString>;
    guide: zod454.ZodOptional<zod454.ZodObject<{
      href: zod454.ZodString;
      title: zod454.ZodString;
    }, "strip", zod454.ZodTypeAny, {
      href: string;
      title: string;
    }, {
      href: string;
      title: string;
    }>>;
    keywords: zod454.ZodOptional<zod454.ZodArray<zod454.ZodString, "many">>;
    logo: zod454.ZodOptional<zod454.ZodObject<{
      alt: zod454.ZodString;
      height: zod454.ZodOptional<zod454.ZodNumber>;
      src: zod454.ZodString;
      width: zod454.ZodOptional<zod454.ZodNumber>;
    }, "strip", zod454.ZodTypeAny, {
      alt: string;
      src: string;
      height?: number | undefined;
      width?: number | undefined;
    }, {
      alt: string;
      src: string;
      height?: number | undefined;
      width?: number | undefined;
    }>>;
    node: zod454.ZodObject<{
      minimum: zod454.ZodString;
      pinned: zod454.ZodOptional<zod454.ZodString>;
    }, "strip", zod454.ZodTypeAny, {
      minimum: string;
      pinned?: string | undefined;
    }, {
      minimum: string;
      pinned?: string | undefined;
    }>;
    owner: zod454.ZodString;
    packageData: zod454.ZodOptional<zod454.ZodObject<{
      dependencies: zod454.ZodOptional<zod454.ZodRecord<zod454.ZodString, zod454.ZodString>>;
      devDependencies: zod454.ZodOptional<zod454.ZodRecord<zod454.ZodString, zod454.ZodString>>;
      peerDependencies: zod454.ZodOptional<zod454.ZodRecord<zod454.ZodString, zod454.ZodString>>;
      peerDependenciesMeta: zod454.ZodOptional<zod454.ZodRecord<zod454.ZodString, zod454.ZodUnknown>>;
      scripts: zod454.ZodOptional<zod454.ZodRecord<zod454.ZodString, zod454.ZodOptional<zod454.ZodString>>>;
    }, "strip", zod454.ZodTypeAny, {
      dependencies?: Record<string, string> | undefined;
      devDependencies?: Record<string, string> | undefined;
      peerDependencies?: Record<string, string> | undefined;
      peerDependenciesMeta?: Record<string, unknown> | undefined;
      scripts?: Record<string, string | undefined> | undefined;
    }, {
      dependencies?: Record<string, string> | undefined;
      devDependencies?: Record<string, string> | undefined;
      peerDependencies?: Record<string, string> | undefined;
      peerDependenciesMeta?: Record<string, unknown> | undefined;
      scripts?: Record<string, string | undefined> | undefined;
    }>>;
    pnpm: zod454.ZodOptional<zod454.ZodString>;
    repository: zod454.ZodString;
    rulesetId: zod454.ZodOptional<zod454.ZodString>;
    title: zod454.ZodString;
    type: zod454.ZodOptional<zod454.ZodUnion<[zod454.ZodLiteral<"commonjs">, zod454.ZodLiteral<"module">]>>;
    version: zod454.ZodOptional<zod454.ZodString>;
    words: zod454.ZodOptional<zod454.ZodArray<zod454.ZodString, "many">>;
    workflowsVersions: zod454.ZodOptional<zod454.ZodRecord<zod454.ZodString, zod454.ZodRecord<zod454.ZodString, zod454.ZodObject<{
      hash: zod454.ZodOptional<zod454.ZodString>;
      pinned: zod454.ZodOptional<zod454.ZodBoolean>;
    }, "strip", zod454.ZodTypeAny, {
      hash?: string | undefined;
      pinned?: boolean | undefined;
    }, {
      hash?: string | undefined;
      pinned?: boolean | undefined;
    }>>>>;
  }>;
};
//#endregion
export { presetCommon, presetEverything, presetMinimal, presets };
//# sourceMappingURL=index.d.ts.map